# Georideapilib
![Logo Georide](georide-logo.png)

⚠️ this is not an official implementation

Official georide website: https://georide.fr/

This library can control your georide tracker tracker


Some code have been taken from @alexmohr https://github.com/alexmohr/sonyapilib

This library is used as communication interface in a home assistant component to control media players, which can be found here:(Not ready yet ;))

At the moment not all functions offered by the api are implemented. If you miss a function feel free to create a pull request or open a feature request.

# Installation
To install simply run
```
pip install georideapilib
```

This library has been tested with python 3.7 and above, functionality for older python version cannot be guaranteed.

## Main repo:
	- https://git.tontontux.fr/mduval/pyGeoride
## Github repo:
 	- https://github.com/ptimatth/pyGeoride

## Todo
- [ ] Add support of SocketIO connection
- [ ] Add support of "Get a shared trip" endpoint
